==> kubernetes-model-gatewayapi-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GatewayFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewayFluent<A extends GatewayFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public GatewayFluent.MetadataNested<A> withNewMetadata();
  public GatewayFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public GatewayFluent.MetadataNested<A> editMetadata();
  public GatewayFluent.MetadataNested<A> editOrNewMetadata();
  public GatewayFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public GatewaySpec getSpec();
  public GatewaySpec buildSpec();
  public A withSpec(GatewaySpec spec);
  public Boolean hasSpec();
  public GatewayFluent.SpecNested<A> withNewSpec();
  public GatewayFluent.SpecNested<A> withNewSpecLike(GatewaySpec item);
  public GatewayFluent.SpecNested<A> editSpec();
  public GatewayFluent.SpecNested<A> editOrNewSpec();
  public GatewayFluent.SpecNested<A> editOrNewSpecLike(GatewaySpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public GatewayStatus getStatus();
  public GatewayStatus buildStatus();
  public A withStatus(GatewayStatus status);
  public Boolean hasStatus();
  public GatewayFluent.StatusNested<A> withNewStatus();
  public GatewayFluent.StatusNested<A> withNewStatusLike(GatewayStatus item);
  public GatewayFluent.StatusNested<A> editStatus();
  public GatewayFluent.StatusNested<A> editOrNewStatus();
  public GatewayFluent.StatusNested<A> editOrNewStatusLike(GatewayStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<GatewayFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,GatewaySpecFluent<GatewayFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,GatewayStatusFluent<GatewayFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/GatewayFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.GatewaySpecFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.GatewaySpec;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.GatewayStatus;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.GatewayStatusFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewayFluent<A extends GatewayFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public GatewayFluent.MetadataNested<A> withNewMetadata();
  public GatewayFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public GatewayFluent.MetadataNested<A> editMetadata();
  public GatewayFluent.MetadataNested<A> editOrNewMetadata();
  public GatewayFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public GatewaySpec getSpec();
  public GatewaySpec buildSpec();
  public A withSpec(GatewaySpec spec);
  public Boolean hasSpec();
  public GatewayFluent.SpecNested<A> withNewSpec();
  public GatewayFluent.SpecNested<A> withNewSpecLike(GatewaySpec item);
  public GatewayFluent.SpecNested<A> editSpec();
  public GatewayFluent.SpecNested<A> editOrNewSpec();
  public GatewayFluent.SpecNested<A> editOrNewSpecLike(GatewaySpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public GatewayStatus getStatus();
  public GatewayStatus buildStatus();
  public A withStatus(GatewayStatus status);
  public Boolean hasStatus();
  public GatewayFluent.StatusNested<A> withNewStatus();
  public GatewayFluent.StatusNested<A> withNewStatusLike(GatewayStatus item);
  public GatewayFluent.StatusNested<A> editStatus();
  public GatewayFluent.StatusNested<A> editOrNewStatus();
  public GatewayFluent.StatusNested<A> editOrNewStatusLike(GatewayStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<GatewayFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,GatewaySpecFluent<GatewayFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,GatewayStatusFluent<GatewayFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
